@@ -9,6 +9,7 @@ import           Test.Framework                                         (default
 
 
 --------------------------------------------------------------------------------
+import qualified Language.Haskell.Stylish.Config.Tests
 import qualified Language.Haskell.Stylish.Parse.Tests
 import qualified Language.Haskell.Stylish.Step.Imports.Tests
 import qualified Language.Haskell.Stylish.Step.LanguagePragmas.Tests
@@ -23,6 +24,7 @@ import qualified Language.Haskell.Stylish.Step.UnicodeSyntax.Tests
 main :: IO ()
 main = defaultMain
     [ Language.Haskell.Stylish.Parse.Tests.tests
+    , Language.Haskell.Stylish.Config.Tests.tests
     , Language.Haskell.Stylish.Step.Imports.Tests.tests
     , Language.Haskell.Stylish.Step.LanguagePragmas.Tests.tests
     , Language.Haskell.Stylish.Step.SimpleAlign.Tests.tests
